General · Chart.js documentation
Author: chartjs

# General Configuration

These sections describe general configuration options that can apply elsewhere in the documentation.

- Responsive defines responsive chart options that apply to all charts.
- Device Pixel Ratio defines the ratio between display pixels and rendered pixels.
- Interactions defines options that reflect how hovering chart elements works.
- Options scriptable and indexable options syntax.
- Colors defines acceptable color values.
- Font defines various font options.

# results matching ""

# No results matching ""